@@ -9,4 +9,4 @@ import warnings
 warnings.warn('"allure.adaptor" is deprecated, use "allure.pytest_plugin" instead.')
 
 # impersonate the old ``adaptor``
-from allure.pytest_plugin import *  # @UnusedWildImport
+from allure.pytest_plugin import *  # @UnusedWildImport  # noqa
